==> qtjambi-qt3drender-6.2.11-sources.jar: io/qt/qt3d/render/QRenderCapture.java <==
package io.qt.qt3d.render;


/**
 * <p>Frame graph node for render capture</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html">Qt3DRender::QRenderCapture</a></p>
 */
public class QRenderCapture extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderCapture.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderCapture(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderCapture() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html#QRenderCapture">Qt3DRender::QRenderCapture::QRenderCapture(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderCapture(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderCapture instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html#requestCapture-1">Qt3DRender::QRenderCapture::requestCapture()</a></p>
     */
    public final io.qt.qt3d.render.QRenderCaptureReply requestCapture(){
        return requestCapture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native io.qt.qt3d.render.QRenderCaptureReply requestCapture_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html#requestCapture-2">Qt3DRender::QRenderCapture::requestCapture(QRect)</a></p>
     */
    public final io.qt.qt3d.render.QRenderCaptureReply requestCapture(io.qt.core.QRect rect){
        return requestCapture_native_cref_QRect(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rect));
    }
    
    private native io.qt.qt3d.render.QRenderCaptureReply requestCapture_native_cref_QRect(long __this__nativeId, long rect);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRenderCaptureReply requestCapture(int captureId){
        return requestCapture_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), captureId);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QRenderCaptureReply requestCapture_native_int(long __this__nativeId, int captureId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderCapture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderCapture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderCapture instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QRenderCapture.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Frame graph node for render capture</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html">Qt3DRender::QRenderCapture</a></p>
 */
public class QRenderCapture extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderCapture.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderCapture(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderCapture() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html#QRenderCapture">Qt3DRender::QRenderCapture::QRenderCapture(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderCapture(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderCapture instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html#requestCapture-1">Qt3DRender::QRenderCapture::requestCapture()</a></p>
     */
    public final io.qt.qt3d.render.@Nullable QRenderCaptureReply requestCapture(){
        return requestCapture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native io.qt.qt3d.render.QRenderCaptureReply requestCapture_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendercapture.html#requestCapture-2">Qt3DRender::QRenderCapture::requestCapture(QRect)</a></p>
     */
    public final io.qt.qt3d.render.@Nullable QRenderCaptureReply requestCapture(io.qt.core.@NonNull QRect rect){
        return requestCapture_native_cref_QRect(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rect));
    }
    
    private native io.qt.qt3d.render.QRenderCaptureReply requestCapture_native_cref_QRect(long __this__nativeId, long rect);
    
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QRenderCaptureReply requestCapture(int captureId){
        return requestCapture_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), captureId);
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QRenderCaptureReply requestCapture_native_int(long __this__nativeId, int captureId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QRenderCapture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRenderCapture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRenderCapture instance, QDeclarativeConstructor constructor);
    
}
